Class: Nonnative::NotFoundError
- Inherits:
-
Error
- Object
- Error
- Nonnative::NotFoundError
- Defined in:
- lib/nonnative/not_found_error.rb
Overview
Raised when a configured runner cannot be found by name.
This is typically raised by lookup helpers such as: