Class: Nonnative::Observability
- Inherits:
-
HTTPClient
- Object
- HTTPClient
- Nonnative::Observability
- Defined in:
- lib/nonnative/observability.rb
Overview
HTTP client for common observability endpoints exposed by the system under test.
This client is returned by observability and builds endpoint paths from Configuration#name.
Endpoints:
/<name>/healthz/<name>/livez/<name>/readyz/<name>/metrics
Requests are performed using HTTPClient, so callers may pass RestClient options
such as headers, open_timeout, and read_timeout.
Instance Method Summary collapse
-
#health(opts = {}) ⇒ RestClient::Response, String
Calls
/<name>/healthz. -
#liveness(opts = {}) ⇒ RestClient::Response, String
Calls
/<name>/livez. -
#metrics(opts = {}) ⇒ RestClient::Response, String
Calls
/<name>/metrics. -
#readiness(opts = {}) ⇒ RestClient::Response, String
Calls
/<name>/readyz.
Instance Method Details
#health(opts = {}) ⇒ RestClient::Response, String
Calls /<name>/healthz.
34 35 36 |
# File 'lib/nonnative/observability.rb', line 34 def health(opts = {}) get("#{name}/healthz", opts) end |
#liveness(opts = {}) ⇒ RestClient::Response, String
Calls /<name>/livez.
42 43 44 |
# File 'lib/nonnative/observability.rb', line 42 def liveness(opts = {}) get("#{name}/livez", opts) end |
#metrics(opts = {}) ⇒ RestClient::Response, String
Calls /<name>/metrics.
58 59 60 |
# File 'lib/nonnative/observability.rb', line 58 def metrics(opts = {}) get("#{name}/metrics", opts) end |
#readiness(opts = {}) ⇒ RestClient::Response, String
Calls /<name>/readyz.
50 51 52 |
# File 'lib/nonnative/observability.rb', line 50 def readiness(opts = {}) get("#{name}/readyz", opts) end |