Class: Nonnative::Ports
- Inherits:
-
Object
- Object
- Nonnative::Ports
- Defined in:
- lib/nonnative/ports.rb
Overview
Performs aggregate TCP readiness/shutdown checks for all configured runner ports.
A runner is considered ready only when every configured port is open, and stopped only when every configured port is closed.
Instance Method Summary collapse
-
#closed? ⇒ Boolean
Returns whether all configured ports become non-connectable before their timeouts elapse.
-
#initialize(runner) ⇒ Ports
constructor
A new instance of Ports.
-
#open? ⇒ Boolean
Returns whether all configured ports become connectable before their timeouts elapse.
Constructor Details
Instance Method Details
#closed? ⇒ Boolean
Returns whether all configured ports become non-connectable before their timeouts elapse.
26 27 28 |
# File 'lib/nonnative/ports.rb', line 26 def closed? ports.all?(&:closed?) end |
#open? ⇒ Boolean
Returns whether all configured ports become connectable before their timeouts elapse.
19 20 21 |
# File 'lib/nonnative/ports.rb', line 19 def open? ports.all?(&:open?) end |